#
# spec file for package python-tokenizers
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} && 0%{?suse_version} < 1550
%global force_gcc_version 13
%endif

%{?sle15_python_module_pythons}
Name:           python-tokenizers
Version:        0.21.0
Release:        2.0.2.1.sr20250101
Summary:        Provides an implementation of today's most used tokenizers
License:        Apache-2.0
URL:            https://github.com/huggingface/tokenizers
Source0:        https://github.com/huggingface/tokenizers/archive/refs/tags/v%{version}.tar.gz#/tokenizers-%{version}.tar.gz
Source1:        registry.tar.zst
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module maturin}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  cargo-packaging
BuildRequires:  fdupes
BuildRequires:  gcc%{?force_gcc_version}-c++
BuildRequires:  python-rpm-macros
BuildRequires:  zstd
ExclusiveArch:  %{rust_tier1_arches} riscv64
Requires:       python-huggingface-hub
%python_subpackages

%description
Provides an implementation of today's most used tokenizers, with a focus on
performance and versatility.
* Train new vocabularies and tokenize, using today's most used tokenizers.
* Extremely fast (both training and tokenization), thanks to the Rust
  implementation. Takes less than 20 seconds to tokenize a GB of text on a
  server's CPU.
* Easy to use, but also extremely versatile.
* Designed for research and production.
* Normalization comes with alignments tracking. It's always possible to get the
  part of the original sentence that corresponds to a given token.
* Does all the pre-processing: Truncate, Pad, add the special tokens your model
  needs.

%prep
%autosetup -p1 -n tokenizers-%{version}
rm -rfv .cargo
tar xf %{S:1} -C $PWD

%build
export CARGO_HOME=$PWD/.cargo
export CARGO_NET_OFFLINE=true
export CARGO_PROFILE_RELEASE_DEBUG=full
export CARGO_PROFILE_RELEASE_SPLIT_DEBUGINFO=off
export CARGO_PROFILE_RELEASE_STRIP=false
%if 0%{?force_gcc_version}
export CC="gcc-%{?force_gcc_version}"
export CXX="g++-%{?force_gcc_version}"
%endif
pushd bindings/python
%pyproject_wheel
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%install
export CARGO_NET_OFFLINE=true
export CARGO_PROFILE_RELEASE_DEBUG=full
export CARGO_PROFILE_RELEASE_SPLIT_DEBUGINFO=off
export CARGO_PROFILE_RELEASE_STRIP=false
pushd bindings/python
%pyproject_install
%python_expand %fdupes %{buildroot}/%{$python_sitearch}/*

%check
export CARGO_HOME=$PWD/.cargo
%if 0%{?force_gcc_version}
export CC="gcc-%{?force_gcc_version}"
export CXX="g++-%{?force_gcc_version}"
%endif
# See https://doc.rust-lang.org/cargo/reference/config.html#hierarchical-structure
%{cargo_test} --manifest-path ./tokenizers/Cargo.toml --lib

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitearch}/tokenizers*

%changelog
* Thu Jan  9 2025 Andreas Schwab <schwab@suse.de>
- Enable build on riscv64
* Wed Dec 18 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 0.21.0:
  * More cache options.
  * Disable caching for long strings.
  * Testing ABI3 wheels to reduce number of wheels
  * Adding an API for decode streaming.
  * Decode stream python
  * Fix encode_batch and encode_batch_fast to accept ndarrays again
* Thu Nov  7 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Select only rust tier 1 arches.
- Update registry.tar.zst dependencies
- Update version to 0.20.3:
  * fix pylist
  * [MINOR:TYP] Fix docstrings
- Updates from 0.20.2:
  * Bump cookie and express in /tokenizers/examples/unstable_wasm/www
  * Fix off-by-one error in tokenizer::normalizer::Range::len
  * Arg name correction: auth_token -> token
  * Unsound call of set_var
  * Add safety comments
  * PyO3 0.22
- Updates from 0.20.1:
  * Update README.md
  * fix benchmark file link
  * [ignore_merges] Fix offsets
  * Bump body-parser and express in /tokenizers/examples/unstable_wasm/www
  * Bump serve-static and express in /tokenizers/examples/unstable_wasm/www
  * Bump send and express in /tokenizers/examples/unstable_wasm/www
  * Bump webpack from 5.76.0 to 5.95.0 in /tokenizers/examples/unstable_wasm/www
  * Fix documentation build
  * style: simplify string formatting for readability
* Sun Nov  3 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Experiment with cargo vendor home registry. See documentation:
  https://github.com/openSUSE-Rust/obs-service-cargo/blob/master/README.md#cargo-vendor-home-registry
* Mon Sep 23 2024 Simon Lees <sflees@suse.de>
- Don't use macros for Requires
* Fri Aug 30 2024 Simon Lees <sflees@suse.de>
- Update package name back to "huggingface-hub" to match pypi
* Tue Aug 27 2024 Guang Yee <gyee@suse.com>
- Update package name "huggingface-hub" to "huggingface_hub"
* Tue Aug 20 2024 Simon Lees <sflees@suse.de>
- Fix testsuite on 15.6
* Sun Aug 18 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Replace vendor tarball to zstd compressed vendor tarball
- Force gcc version on leap. Thanks @marv7000 for your zed.spec
- Use `CARGO_*` environmental variables to force generate
  full debuginfo and avoid stripping.
- Enable cargo test in %%check.
- Update to version 0.20.0:
  * remove enforcement of non special when adding tokens
  * [BREAKING CHANGE] Ignore added_tokens (both special and not) in the decoder
  * Make USED_PARALLELISM atomic
  * Fixing for clippy 1.78
  * feat(ci): add trufflehog secrets detection
  * Switch from cached_download to hf_hub_download in tests
  * Fix "dictionnary" typo
  * make sure we don't warn on empty tokens
  * Enable dropout = 0.0 as an equivalent to none in BPE
  * Revert "[BREAKING CHANGE] Ignore added_tokens (both special and not) …
  * Add bytelevel normalizer to fix decode when adding tokens to BPE
  * Fix clippy + feature test management.
  * Bump spm_precompiled to 0.1.3
  * Add benchmark vs tiktoken
  * Fixing the benchmark.
  * Tiny improvement
  * Enable fancy regex
  * Fixing release CI strict (taken from safetensors).
  * Adding some serialization testing around the wrapper.
  * Add-legacy-tests
  * Adding a few tests for decoder deserialization.
  * Better serialization error
  * Add test normalizers
  * Improve decoder deserialization
  * Using serde (serde_pyo3) to get str and repr easily.
  * Merges cannot handle tokens containing spaces.
  * Fix doc about split
  * Support None to reset pre_tokenizers and normalizers, and index sequences
  * Fix strip python type
  * Tests + Deserialization improvement for normalizers.
  * add deserialize for pre tokenizers
  * Perf improvement 16%% by removing offsets.
* Wed Jul  3 2024 Christian Goll <cgoll@suse.com>
- initial commit on rust based python-tokenizers
